using System;
using System.Collections.Generic;
using System.Configuration;
using System.Globalization;
using System.Xml;

namespace MockDataProvider.Configuration
{
    internal sealed class SectionHandler : IConfigurationSectionHandler
    {
        #region IConfigurationSectionHandler Members

        public object Create( object parent, object configContext, XmlNode section )
        {
            if ( section == null )
                throw new ConfigurationErrorsException( "Mock ADO.NET Data Provider configuration section not found" );

            #region General Configuration

            string realDataProvider = String.Empty;
            if ( section.Attributes[ "realDataProvider" ] != null && !String.IsNullOrEmpty( section.Attributes[ "realDataProvider" ].Value ) )
                realDataProvider = section.Attributes[ "realDataProvider" ].Value;

            string cacheFile = String.Empty;
            if ( section.Attributes[ "cacheFile" ] != null && !String.IsNullOrEmpty( section.Attributes[ "cacheFile" ].Value ) )
                cacheFile = section.Attributes[ "cacheFile" ].Value;

            bool mockMode = true;
            if ( section.Attributes[ "mockMode" ] != null )
                mockMode = Convert.ToBoolean( section.Attributes[ "mockMode" ].Value, CultureInfo.InvariantCulture );

            #endregion

            return new ConfigurationInformation( realDataProvider, cacheFile, mockMode );
        }

        #endregion
    }
}